<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * Admin functions used by the GetSimple Sidebar Links Plugin.
 */

/*******************************************************
 * @function sl_admin_panel
 * @action give an overview of all links in the database
 */
function sl_admin_panel() {
  include(SLTEMPLATEPATH . 'panel_header.php');
  $links = sl_get_links();
  if (!empty($links)) {
    echo '<table class="highlight">';
    include(SLTEMPLATEPATH . 'panel_table_header.php');
    foreach ($links as $id=>$link) {
      $name = $link['name'];
      $url = $link['url'];
      include(SLTEMPLATEPATH . 'panel_table_row.php');
    }
    echo '</table>';
  }
  echo '<p><b>' . count($links) . '</b> ' . i18n_r('sidebar_links/LINKS') . '</p>';
}


/*******************************************************
 * @function sl_edit_link
 * @param $id unique link identifier
 * @action create a new link or edit an existing one
 */
function sl_edit_link($id=null) {
  if (isset($id)) {
    $links = sl_get_links();
    if (array_key_exists($id, $links))
      $link = $links[$id];
  }
  include(SLTEMPLATEPATH . 'edit_link.php');
}


/*******************************************************
 * @function sl_save_link
 * @action collect $_POST data and write to file
 */
function sl_save_link() {
  $id = isset($_POST['link-id']) ? $_POST['link-id'] : sl_uniqid();
  $name = safe_slash_html($_POST['link-name']);
  $url = $_POST['link-url'];
  $links = sl_get_links();
  $links[$id] = array('name'=>$name, 'url'=>$url);
  if (sl_write_data($links))
    sl_display_message(i18n_r('sidebar_links/SUCCESS_SAVE_LINK'));
  else
    sl_display_message(i18n_r('sidebar_links/ERROR_SAVE_LINK'), TRUE);
}


/*******************************************************
 * @function sl_delete_link
 * @param $id unique link identifier
 * @action remove link with given $id
 */
function sl_delete_link($id) {
  $links = sl_get_links();
  if (array_key_exists($id, $links)) {
    unset($links[$id]);
    if (sl_write_data($links))
      sl_display_message(i18n_r('sidebar_links/SUCCESS_DELETE_LINK'));
    else
      sl_display_message(i18n_r('sidebar_links/ERROR_DELETE_LINK'), TRUE);
  }
}


/*******************************************************
 * @function sl_write_data
 * @param $links array with link data
 * @action write link data to file
 * @return true when successful, false otherwise
 */
function sl_write_data($links) {
  $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><data></data>');
  foreach ($links as $id=>$link) {
    $child = $xml->addChild('link');
    $obj = $child->addChild('id');
    $obj->addCData($id);
    $obj = $child->addChild('name');
    $obj->addCData($link['name']);
    $obj = $child->addChild('url');
    $obj->addCData($link['url']);
  }
  return @XMLsave($xml, SLDATAFILE);
}


?>
